@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,10 +20,10 @@
 
 #include <QListView>
 #include "invalidfilterinfo.h"
-#include "mailcommon_export.h"
+#include "mailcommon_private_export.h"
 
 namespace MailCommon {
-class MAILCOMMON_EXPORT InvalidFilterListView : public QListView
+class MAILCOMMON_TESTS_EXPORT InvalidFilterListView : public QListView
 {
     Q_OBJECT
 public:
