@@ -51,7 +51,7 @@ public:
     void handleMessages();
 
     SendMdnHandler *q;
-    IKernel *mKernel;
+    IKernel *mKernel = nullptr;
     QQueue<Akonadi::Item> mItemQueue;
     QTimer mTimer;
 };
@@ -111,7 +111,9 @@ SendMdnHandler::SendMdnHandler(IKernel *kernel, QObject *parent)
     , d(new Private(this, kernel))
 {
     d->mTimer.setSingleShot(true);
-    connect(&d->mTimer, SIGNAL(timeout()), this, SLOT(handleMessages()));
+    connect(&d->mTimer, &QTimer::timeout, this, [this]() {
+        d->handleMessages();
+    });
 }
 
 SendMdnHandler::~SendMdnHandler()
