@@ -45,7 +45,7 @@
 #include "folder/foldersettings.h"
 #include "pop3settings.h"
 #include "kernel/mailkernel.h"
-#include "filter/dialog/filteractionmissingargumentdialog.h"
+#include "filter/dialog/filteractionmissingfolderdialog.h"
 
 #include "mailimporter/filterbalsa.h"
 #include "mailimporter/filterevolution.h"
@@ -69,11 +69,11 @@
 #include <ItemFetchScope>
 #include <Akonadi/KMime/MessageParts>
 #include <AkonadiCore/NewMailNotifierAttribute>
+#include <AkonadiCore/ServerManager>
 
 #include <KMime/KMimeMessage>
 
 #include <KColorScheme>
-#include <KDBusServiceStarter>
 #include <KJob>
 #include <KIO/JobUiDelegate>
 #include <collectionpage/attributes/expirecollectionattribute.h>
@@ -81,26 +81,29 @@
 OrgKdeAkonadiPOP3SettingsInterface *MailCommon::Util::createPop3SettingsInterface(
     const QString &ident)
 {
-    return
-        new OrgKdeAkonadiPOP3SettingsInterface(
-        QLatin1String("org.freedesktop.Akonadi.Resource.") + ident, QStringLiteral("/Settings"), QDBusConnection::sessionBus());
+    const auto service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, ident);
+    return new OrgKdeAkonadiPOP3SettingsInterface(service, QStringLiteral("/Settings"), QDBusConnection::sessionBus());
 }
 
 bool MailCommon::Util::isVirtualCollection(const Akonadi::Collection &collection)
 {
-    return MailCommon::Util::isVirtualCollection(collection.resource());
+    return collection.isVirtual() || MailCommon::Util::isVirtualCollection(collection.resource());
 }
 
 bool MailCommon::Util::isVirtualCollection(const QString &resource)
 {
-    return resource == QLatin1String("akonadi_search_resource");
+    if (resource == QLatin1String("akonadi_search_resource")) {
+        return true;
+    }
+
+    const auto type = Akonadi::AgentManager::self()->type(resource);
+    return type.capabilities().contains(QLatin1String("Virtual"));
 }
 
 bool MailCommon::Util::isLocalCollection(const QString &resource)
 {
-    return resource.contains(QStringLiteral("akonadi_mbox_resource"))
-           || resource.contains(QStringLiteral("akonadi_maildir_resource"))
-           || resource.contains(QStringLiteral("akonadi_mixedmaildir_resource"));
+    auto type = Akonadi::AgentManager::self()->type(resource);
+    return type.customProperties().value(QStringLiteral("HasLocalStorage"), false).toBool();
 }
 
 QString MailCommon::Util::fullCollectionPath(const Akonadi::Collection &collection, bool addAccountName)
@@ -135,7 +138,7 @@ QString MailCommon::Util::fullCollectionPath(const Akonadi::Collection &collecti
 bool MailCommon::Util::showJobErrorMessage(KJob *job)
 {
     if (job->error()) {
-        if (auto uidelegate = static_cast<KIO::Job *>(job)->ui()) {
+        if (auto uidelegate = static_cast<KIO::Job *>(job)->uiDelegate()) {
             uidelegate->showErrorMessage();
         } else {
             qCDebug(MAILCOMMON_LOG) << " job->errorString() :" << job->errorString();
@@ -152,9 +155,9 @@ Akonadi::AgentInstance::List MailCommon::Util::agentInstances(bool excludeMailDi
     for (const Akonadi::AgentInstance &instance : agentList) {
         const QStringList capabilities(instance.type().capabilities());
         if (instance.type().mimeTypes().contains(KMime::Message::mimeType())) {
-            if (capabilities.contains(QStringLiteral("Resource"))
-                && !capabilities.contains(QStringLiteral("Virtual"))
-                && !capabilities.contains(QStringLiteral("MailTransport"))) {
+            if (capabilities.contains(QLatin1String("Resource"))
+                && !capabilities.contains(QLatin1String("Virtual"))
+                && !capabilities.contains(QLatin1String("MailTransport"))) {
                 relevantInstances << instance;
             } else if (!excludeMailDispacher
                        && instance.identifier() == QLatin1String("akonadi_maildispatcher_agent")) {
@@ -171,7 +174,7 @@ uint MailCommon::Util::folderIdentity(const Akonadi::Item &item)
     if (item.isValid() && item.parentCollection().isValid()) {
         Akonadi::Collection col = item.parentCollection();
         if (col.resource().isEmpty()) {
-            col = parentCollectionFromItem(item);
+            col = CommonKernel->collectionFromId(col.id());
         }
         const QSharedPointer<FolderSettings> fd
             = FolderSettings::forCollection(col, false);
@@ -181,112 +184,6 @@ uint MailCommon::Util::folderIdentity(const Akonadi::Item &item)
     return id;
 }
 
-static QModelIndex indexBelow(QAbstractItemModel *model, const QModelIndex &current)
-{
-    // if we have children, return first child
-    if (model->rowCount(current) > 0) {
-        return model->index(0, 0, current);
-    }
-
-    // if we have siblings, return next sibling
-    const QModelIndex parent = model->parent(current);
-    const QModelIndex sibling = model->index(current.row() + 1, 0, parent);
-
-    if (sibling.isValid()) {   // found valid sibling
-        return sibling;
-    }
-
-    if (!parent.isValid()) {   // our parent is the tree root and we have no siblings
-        return QModelIndex(); // we reached the bottom of the tree
-    }
-
-    // We are the last child, the next index to check is our uncle, parent's first sibling
-    const QModelIndex parentsSibling = parent.sibling(parent.row() + 1, 0);
-    if (parentsSibling.isValid()) {
-        return parentsSibling;
-    }
-
-    // iterate over our parents back to root until we find a parent with a valid sibling
-    QModelIndex currentParent = parent;
-    QModelIndex grandParent = model->parent(currentParent);
-    while (currentParent.isValid()) {
-        // check if the parent has children except from us
-        if (model->rowCount(grandParent) > currentParent.row() + 1) {
-            const QModelIndex index
-                = indexBelow(model, model->index(currentParent.row() + 1, 0, grandParent));
-            if (index.isValid()) {
-                return index;
-            }
-        }
-
-        currentParent = grandParent;
-        grandParent = model->parent(currentParent);
-    }
-
-    return QModelIndex(); // nothing found -> end of tree
-}
-
-static QModelIndex lastChildOfModel(QAbstractItemModel *model, const QModelIndex &current)
-{
-    if (model->rowCount(current) == 0) {
-        return current;
-    }
-
-    return lastChildOfModel(model, model->index(model->rowCount(current) - 1, 0, current));
-}
-
-static QModelIndex indexAbove(QAbstractItemModel *model, const QModelIndex &current)
-{
-    const QModelIndex parent = model->parent(current);
-
-    if (current.row() == 0) {
-        // we have no previous siblings -> our parent is the next item above us
-        return parent;
-    }
-
-    // find previous sibling
-    const QModelIndex previousSibling = model->index(current.row() - 1, 0, parent);
-
-    // the item above us is the last child (or grandchild, or grandgrandchild... etc)
-    // of our previous sibling
-    return lastChildOfModel(model, previousSibling);
-}
-
-QModelIndex MailCommon::Util::nextUnreadCollection(QAbstractItemModel *model, const QModelIndex &current, SearchDirection direction, bool (*ignoreCollectionCallback)(
-                                                       const Akonadi::Collection &collection))
-{
-    QModelIndex index = current;
-    while (true) {
-        if (direction == MailCommon::Util::ForwardSearch) {
-            index = indexBelow(model, index);
-        } else if (direction == MailCommon::Util::BackwardSearch) {
-            index = indexAbove(model, index);
-        }
-
-        if (!index.isValid()) {   // reach end or top of the model
-            return QModelIndex();
-        }
-
-        // check if the index is a collection
-        const Akonadi::Collection collection
-            = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-
-        if (collection.isValid()) {
-            // check if it is unread
-            if (collection.statistics().unreadCount() > 0) {
-                if (ignoreCollectionCallback && ignoreCollectionCallback(collection)) {
-                    continue;
-                }
-                if (!ignoreNewMailInFolder(collection)) {
-                    return index; // we found the next unread collection
-                }
-            }
-        }
-    }
-
-    return QModelIndex(); // no unread collection found
-}
-
 bool MailCommon::Util::ignoreNewMailInFolder(const Akonadi::Collection &collection)
 {
     if (collection.hasAttribute<Akonadi::NewMailNotifierAttribute>()) {
@@ -297,11 +194,6 @@ bool MailCommon::Util::ignoreNewMailInFolder(const Akonadi::Collection &collecti
     return false;
 }
 
-Akonadi::Collection MailCommon::Util::parentCollectionFromItem(const Akonadi::Item &item)
-{
-    return updatedCollection(item.parentCollection());
-}
-
 QString MailCommon::Util::realFolderPath(const QString &path)
 {
     QString realPath(path);
@@ -325,22 +217,15 @@ void MailCommon::Util::expireOldMessages(const Akonadi::Collection &collection,
     KernelIf->jobScheduler()->registerTask(task);
 }
 
-Akonadi::Collection MailCommon::Util::updatedCollection(const Akonadi::Collection &col)
-{
-    const QModelIndex idx = Akonadi::EntityTreeModel::modelIndexForCollection(KernelIf->collectionModel(), col);
-    const Akonadi::Collection collection = idx.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-    return collection;
-}
-
 Akonadi::Collection::Id MailCommon::Util::convertFolderPathToCollectionId(const QString &folder)
 {
     Akonadi::Collection::Id newFolderId = -1;
     bool exactPath = false;
-    Akonadi::Collection::List lst = FilterActionMissingCollectionDialog::potentialCorrectFolders(folder, exactPath);
+    Akonadi::Collection::List lst = FilterActionMissingFolderDialog::potentialCorrectFolders(folder, exactPath);
     if (lst.count() == 1 && exactPath) {
         newFolderId = lst.at(0).id();
     } else {
-        QPointer<FilterActionMissingCollectionDialog> dlg = new FilterActionMissingCollectionDialog(lst, QString(), folder);
+        QPointer<FilterActionMissingFolderDialog> dlg = new FilterActionMissingFolderDialog(lst, QString(), folder);
         if (dlg->exec()) {
             newFolderId = dlg->selectedCollection().id();
         }
@@ -358,29 +243,30 @@ QString MailCommon::Util::convertFolderPathToCollectionStr(const QString &folder
     return QString::number(newFolderId);
 }
 
-bool MailCommon::Util::foundMailer()
+void MailCommon::Util::foundMailer(QStringList &lst, const QString &name)
 {
-    const QStringList lst = {
-        MailImporter::FilterEvolution::defaultSettingsPath(),
-        MailImporter::FilterEvolution_v2::defaultSettingsPath(),
-        MailImporter::FilterEvolution_v3::defaultSettingsPath(),
-        MailImporter::FilterBalsa::defaultSettingsPath(),
-        MailImporter::FilterClawsMail::defaultSettingsPath(),
-        MailImporter::FilterOpera::defaultSettingsPath(),
-        MailImporter::FilterSylpheed::defaultSettingsPath(),
-        MailImporter::FilterThunderbird::defaultSettingsPath(),
-        MailImporter::OtherMailerUtil::trojitaDefaultPath(),
-        MailImporter::FilterIcedove::defaultSettingsPath(),
-        MailImporter::OtherMailerUtil::gearyDefaultPath()
-    };
-
-    for (const QString &path : lst) {
-        QDir directory(path);
-        if (directory.exists()) {
-            return true;
-        }
+    if (!name.isEmpty()) {
+        lst.append(name);
     }
-    return false;
+}
+
+QStringList MailCommon::Util::foundMailer()
+{
+    QStringList lst;
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterEvolution::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterEvolution_v2::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterEvolution_v3::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterBalsa::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterClawsMail::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterOpera::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterSylpheed::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterThunderbird::isMailerFound());
+    MailCommon::Util::foundMailer(lst, MailImporter::FilterIcedove::isMailerFound());
+    const QStringList otherMailer = MailImporter::OtherMailerUtil::isMailerFound();
+    if (!otherMailer.isEmpty()) {
+        lst << otherMailer;
+    }
+    return lst;
 }
 
 MailCommon::ExpireCollectionAttribute *MailCommon::Util::expirationCollectionAttribute(const Akonadi::Collection &collection, bool &mustDeleteExpirationAttribute)
