@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,15 +26,14 @@
 class KXMLGUIClient;
 class KActionCollection;
 
-namespace MailCommon
-{
-
+namespace MailCommon {
+class MailCommonSettings;
 class MAILCOMMON_EXPORT FavoriteCollectionWidget : public Akonadi::EntityListView
 {
     Q_OBJECT
 public:
-    explicit FavoriteCollectionWidget(KXMLGUIClient *xmlGuiClient, QWidget *parent = nullptr);
-    ~FavoriteCollectionWidget();
+    explicit FavoriteCollectionWidget(MailCommon::MailCommonSettings *settings, KXMLGUIClient *xmlGuiClient, QWidget *parent = nullptr);
+    ~FavoriteCollectionWidget() override;
 
     void readConfig();
     void updateMode();
@@ -48,19 +47,23 @@ protected Q_SLOTS:
     void slotChangeMode(bool);
 
 protected:
-    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *) override;
+    void dragEnterEvent(QDragEnterEvent *event) override;
+    void dragMoveEvent(QDragMoveEvent *event) override;
+    void dropEvent(QDropEvent *event) override;
+    void startDrag(Qt::DropActions) override;
 
-    void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *e) override;
 Q_SIGNALS:
     void newTabRequested(bool);
 
 private:
+    bool acceptEvent(QDropEvent *event) const;
     void createMenu(KActionCollection *ac);
+
     class Private;
     Private *const d;
 };
-
 }
 
 #endif /* MAILCOMMON_FAVORITECOLLECTIONWIDGET_H */
-
