@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -59,6 +59,9 @@ RedirectWidget::RedirectWidget(QWidget *parent)
     connect(BtnTo, &QAbstractButton::clicked, this, &RedirectWidget::slotAddressSelection);
 
     connect(mEdit, &QLineEdit::textChanged, this, &RedirectWidget::addressChanged);
+
+    setFocusPolicy(Qt::StrongFocus);
+    setFocusProxy(mEdit);
 }
 
 RedirectWidget::~RedirectWidget()
